@@ -4,13 +4,13 @@ from typing import Any
 from typing import Dict
 from typing import Optional
 
+from egse.device import AsyncDeviceInterface
 from egse.device import AsyncDeviceTransport
 from egse.device import DeviceConnectionError
 from egse.device import DeviceError
 from egse.device import DeviceTimeoutError
 from egse.log import logger
 
-# Constants that can be overridden by specific device implementations
 DEFAULT_READ_TIMEOUT = 1.0  # seconds
 DEFAULT_CONNECT_TIMEOUT = 3.0  # seconds
 IDENTIFICATION_QUERY = "*IDN?"
@@ -32,7 +32,7 @@ class SCPICommand:
         raise NotImplementedError("Subclasses must implement get_cmd_string().")
 
 
-class AsyncSCPIInterface(AsyncDeviceTransport):
+class AsyncSCPIInterface(AsyncDeviceInterface, AsyncDeviceTransport):
     """Generic asynchronous interface for devices that use SCPI commands over Ethernet."""
 
     def __init__(
@@ -56,6 +56,7 @@ class AsyncSCPIInterface(AsyncDeviceTransport):
             read_timeout: Timeout for read operations in seconds
             id_validation: String that should appear in the device's identification response
         """
+        super().__init__()
         self.device_name = device_name
         self.hostname = hostname
         self.port = port
@@ -73,6 +74,53 @@ class AsyncSCPIInterface(AsyncDeviceTransport):
         """Prevents multiple coroutines from attempting to read, write or query from the same stream
         at the same time."""
 
+    def is_simulator(self) -> bool:
+        return False
+
+    async def initialize(self, commands: list[tuple[str, bool]] = None, reset_device: bool = False):
+        """Initialize the device with optional reset and command sequence.
+
+        Performs device initialization by optionally resetting the device and then
+        executing a sequence of commands. Each command can optionally expect a
+        response that will be logged for debugging purposes.
+
+        Args:
+            commands: List of tuples containing (command_string, expects_response).
+                Each tuple specifies a command to send and whether to wait for and
+                log the response. Defaults to None (no commands executed).
+            reset_device: Whether to send a reset command (*RST) before executing
+                the command sequence. Defaults to False.
+
+        Returns:
+            None
+
+        Raises:
+            Any exceptions raised by the underlying write() or trans() methods,
+            typically communication errors or device timeouts.
+
+        Example:
+            >>> await device.initialize([
+            ...     ("*IDN?", True),           # Query device ID, expect response
+            ...     ("SYST:ERR?", True),       # Check for errors, expect response
+            ...     ("OUTP ON", False)         # Enable output, no response expected
+            ... ], reset_device=True)
+        """
+
+        commands = commands or []
+
+        if reset_device:
+            logger.info(f"Resetting the {self.device_name}...")
+            await self.write("*RST")  # this also resets the user-defined buffer
+
+        for cmd, expects_response in commands:
+            if expects_response:
+                logger.debug(f"Sending {cmd}...")
+                response = (await self.trans(cmd)).decode().strip()
+                logger.debug(f"{response = }")
+            else:
+                logger.debug(f"Sending {cmd}...")
+                await self.write(cmd)
+
     async def connect(self) -> None:
         """Connect to the device asynchronously.
 
@@ -146,11 +194,9 @@ class AsyncSCPIInterface(AsyncDeviceTransport):
 
     async def reconnect(self) -> None:
         """Reconnect to the device asynchronously."""
-        async with self._connect_lock:
-            if self._is_connection_open:
-                await self.disconnect()
-                await asyncio.sleep(0.1)
-            await self.connect()
+        await self.disconnect()
+        await asyncio.sleep(0.1)
+        await self.connect()
 
     async def is_connected(self) -> bool:
         """Check if the device is connected and responds correctly to identification.
@@ -177,8 +223,7 @@ class AsyncSCPIInterface(AsyncDeviceTransport):
             return True
 
         except DeviceError as exc:
-            logger.exception(exc)
-            logger.error(f"{self.device_name}: Connection test failed")
+            logger.error(f"{self.device_name}: Connection test failed: {exc}", exc_info=True)
             await self.disconnect()
             return False
 
@@ -201,6 +246,7 @@ class AsyncSCPIInterface(AsyncDeviceTransport):
                 if not command.endswith("\n"):
                     command += "\n"
 
+                logger.info(f"-----> {command}")
                 self._writer.write(command.encode())
                 await self._writer.drain()
 
@@ -233,6 +279,7 @@ class AsyncSCPIInterface(AsyncDeviceTransport):
                     response = await asyncio.wait_for(
                         self._reader.readuntil(separator=b"\n"), timeout=self.read_timeout
                     )
+                    logger.info(f"<----- {response}")
                     return response
 
                 except asyncio.IncompleteReadError as exc:
@@ -279,6 +326,7 @@ class AsyncSCPIInterface(AsyncDeviceTransport):
                 if not command.endswith("\n"):
                     command += "\n"
 
+                logger.info(f"-----> {command}")
                 self._writer.write(command.encode())
                 await self._writer.drain()
 
@@ -290,6 +338,7 @@ class AsyncSCPIInterface(AsyncDeviceTransport):
                     response = await asyncio.wait_for(
                         self._reader.readuntil(separator=b"\n"), timeout=self.read_timeout
                     )
+                    logger.info(f"<----- {response}")
                     return response
 
                 except asyncio.IncompleteReadError as exc:
